<?PHP 
###########################################################################
# 
# File:            taloLoggerGraph_tempfile.inc (PHP)
#
# License:         Donationware, see attached LICENSE file for more 
#                  information
#
# Author:          Olli Lammi (olammi@iki.fi)
#
# Version:         1.2a
#
# Date:            02.01.2015
#
# Functions:       getTempDir
#                  getImagePath
#                  getTempId
#                   
# Description:     House automation data logger graphing application for PHP. 
# 
#                  Functions to handle the generated images in the 
#                  system temporary directory.
#
# Requirements:    PHP 5 or newer (www.php.net)
#
# Version history: ** 20.10.2010 v0.1a (Olli Lammi) **
#                  First beta version for testers. 
#
#                  ** 04.11.2010 v1.0a (Olli Lammi) **
#                  First version released to the public.
#
#                  ** 05.09.2014 v1.1c (Olli Lammi) **
#                  Configurable temporary file location with environment
#                  variable TLG_TEMP_DIR or hard coded value in this 
#                  file. Added removeOldTempFiles function.
#
#                  ** 02.01.2015 v1.2a (Olli Lammi) **
#                  Support for multiple types on temp files (not just png). 
#
###########################################################################

# if value is nonempty, hard coded temp directory will be used
$OVERRIDE_TEMP_DIR = ''; 

function getTempDir() {
    global $OVERRIDE_TEMP_DIR;
    # OVERRIDE_TEMP_DIR local variable overrides all other values
    if ($OVERRIDE_TEMP_DIR && strlen($OVERRIDE_TEMP_DIR) > 0) {
        return $OVERRIDE_TEMP_DIR;
    }
	
    # TLG_TEMP_DIR environment variable is handled next
    $tlgtempdir = getenv('TLG_TEMP_DIR');
    if ($tlgtempdir && strlen($tlgtempdir) > 0) {
        return $tlgtempdir;
    }
	
    # thirdly use some system function or system variable to determine
    # temp file location
    if (!function_exists('sys_get_temp_dir')) {
        # check environment variables.
        foreach (array('TMP', 'TEMP', 'TMPDIR') as $env_var) {
            if ($temp = getenv($env_var)) {
                return $temp;
            }
        }
        # test for a temp directory by having PHP create a temporary file.
        $temp = tempnam(__FILE__, '');
        if (file_exists($temp)) {
           unlink($temp);
           return dirname($temp);
        }
        # couldn't find a temp directory.
        return null;
    }
    else {
        return sys_get_temp_dir();
    }
}

function getImagePath($id, $type = 'png') {
    return getTempDir() . DIRECTORY_SEPARATOR . 'tlchrt_' . $id . '.' . $type;
}

function getTempId($type = 'png') {
    $id = rand();
    $i = 0;
    while ($i < 10) {
        if (!file_exists(getImagePath($id, $type))) {
            return $id;
        }
        $i += 1;
    }

    return 0;
}

function removeOldTempFiles() {
    # max age of the file in seconds
    $TEMP_FILE_MAX_AGE = 60;

    $tempd = getTempDir() . DIRECTORY_SEPARATOR;

    $temps_to_remove = array();
    if ($dirhandle = opendir($tempd)) {
        while (FALSE !== ($entry = readdir($dirhandle))) {
            if (preg_match('/^tlchrt_\d+\.(png|jpg|html)$/', $entry)) {
                $tfname = $tempd . $entry;
                if (time() - filemtime($tfname) > $TEMP_FILE_MAX_AGE) {
                    $temps_to_remove[] = $tfname;
                }
            }
        }
        closedir($dirhandle);
    }

    foreach ($temps_to_remove as $tfname) {
        unlink($tfname);
    }
}

?>
